Transpose an array (general permutation).
g_transpose.Rdperm[i] names the input axis that becomes output axis i
(base R aperm() semantics); NULL reverses the axes.

g_transpose.Rdperm[i] names the input axis that becomes output axis i
(base R aperm() semantics); NULL reverses the axes.