Skip to contents

TRUE when the read and compute daemon pools created by garry_daemons() are running. This is the default for the distributed argument of collect(), so collect(x) uses the pools when they are up and runs single-threaded otherwise. Mirrors mirai::daemons_set().

Usage

garry_daemons_set()

Value

A single logical.