Skip to contents

NaN cells are converted back to the sink nodata value when given; writing NaN into an integer band without a sentinel is an error.

Usage

gdal_write_window(ds, x_off, y_off, m, dtype, nodata = numeric(0), band = 1L)

Arguments

ds

Open dataset from gdal_create_output().

x_off, y_off

0-based destination offsets.

m

[y, x] matrix.

dtype

Output dtype (for the NaN check).

nodata

Optional sentinel for NaN demotion.

band

1-based destination band.

Value

Invisibly, NULL.