Add a node. ctor is an S7 node constructor; ... are its properties (the id property is assigned here and passed automatically).
graph_add.RdAdd a node. ctor is an S7 node constructor; ... are its properties
(the id property is assigned here and passed automatically).
See also
Other graph functions:
Graph(),
graph_get(),
graph_ids(),
graph_import(),
graph_new(),
graph_replace(),
graph_toposort()