List tensor names, dtypes, and shapes without reading data.
safetensors_ls.RdList tensor names, dtypes, and shapes without reading data.
See also
safetensors_read() to read the tensors.

safetensors_ls.RdList tensor names, dtypes, and shapes without reading data.
safetensors_read() to read the tensors.